<?php

/*
 * @package RS-MINI
 * @copyright (c) 2015 Alexey Glumov aka Rio-Shaman (support@rio-shaman.ru)
 * @license GNU General Public License version 2; see LICENSE.txt
 *
 */
 
namespace core;

if(!defined('RS-MINI')) die();

/*
 * controller v 1.0
 * 
 * Класс хранит инфу о контроллере
 *
 */

class controller
{   
	/*
     * свойство id контроллера
     *
     * @var    - integer
     * @access - public
     */
	
	public $controllerID;
	
	/*
     * свойство имя контроллера
     *
     * @var    - string
     * @access - public
     */
	
	public $controllerName;
	
	/*
     * свойство параметров контроллера (строчка)
     *
     * @var    - string
     * @access - private
     */
	
	private $controllerParam;
	
	/*
     * свойство параметров контроллера (массив)
     *
     * @var    - array
     * @access - private
     */
	
	private $paramList = array();
	
	/*
     * свойство наследования контроллера
     *
     * @var    - boolean
     * @access - public
     */
	
	public $controllerInherit;
	
	/*
     * свойство определяет унаследовался ли контроллер
     *
     * @var    - boolean
     * @access - public
     */
	
	public $inheritFlag = FALSE;

    /*
     * контсруктор. получаем объекты переданные по ссылке
     * 
     * @access - public
     * 
     * @param array connect - массив с полями подключения. в часности важны ключи
     *                        ['controller_id']
     *                        ['controller_name']
     *                        ['connect_value']
     *                        ['connect_inherit']
     */
	
	public function __construct(&$connect)
	{
        // id контроллера (из таблицы rs_controller)
        $this->controllerID      = $connect['controller_id'];
        // имя контроллера (из таблицы rs_controller)
		$this->controllerName    = $connect['controller_name'];
        // строка с параметрами контроллера (из таблицы rs_controller)
		$this->controllerParam   = $connect['connect_value'];
        // флаг позволяющий определить будет ли контроллер
        // наследоваться или нет
		$this->controllerInherit = $connect['connect_inherit'];
		
		// вызов метода который сделает из строки параметров
        // массив
        $this->gatherParam();
	}

	/*
     * метод устанавливаем значение в свойство $this->params
     * 
     * @access - public
     * @return - сам себя
     * 
     */
	
	public function setParam($name, $value)
	{
		$this->paramList[trim($name)] = trim($value);
		
		return $this;
	}
	
	/*
     * метод преобразует строчку параметров в массив
     * 
     * @access - private
     * 
     */
	
	private function gatherParam()
	{
		if (empty($this->controllerParam))
			return;
		
		$paramList = explode("\n", $this->controllerParam);
		
		foreach ($paramList as $row) {
			$param                              = explode(':', trim($row));
			$this->paramList[trim($param[0])]   = trim($param[1]);
		}
	}
	
	/*
     * метод возвращает параметры
     * 
     * @access - public
     * @return - массив с параметрами или null
     */
	
	public function getParams()
	{
		return (!empty($this->paramList)) ? $this->paramList : NULL;
	}

	/*
     * метод возвращает параметр
     * 
     * @access - public
     * @return - строку с значением или null
     *
     * @param string name - имя параметра
     */
	
	public function getParam($name)
	{
		return (isset($this->paramList[$name])) ? $this->paramList[$name] : NULL;
	}
    
	/*
     * метод перезаписывает существующие параметры
     * 
     * @access - public
     *
     * @param array params - массив с унаследованными параметрами
     */
	
	public function unionParams($params)
	{
		// если параметров у контроллера нет
        if (empty($this->paramList)) {
			// просто сохраняем то что прислали
            $this->paramList = $params;
			return;
		}
		
		// если параметры есть, то листаем присланные
        foreach($params as $inheritName => $inheritValue) {
			
			// переменная для определения есть ли уже такой параметр
            // у контроллера
            $found = FALSE;
			
			// листаем параметры контроллеров и сравниваем имена
            foreach ($this->paramList as $name => $value)
				// если имена равны
                if ($inheritName == $name)
					// переключаем переменную в состояние "найдено"
                    $found = TRUE;
					
			// если присланный параметр небыл найден у контроллера
            if ($found == FALSE)
				// сохраняем его
                $this->paramList[$inheritName] = $inheritValue;
		}
	}
}
